@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.82 2003/11/02 01:58:05 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.94 2004/01/31 20:47:11 trow Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -67,7 +67,7 @@ enum {
 	GOT_METADATA,
 	BUFFERING,
 	SPEED_WARNING,
-	LAST_SIGNAL,
+	LAST_SIGNAL
 };
 
 /* Enum for none-signal stuff that needs to go through the AsyncQueue */
@@ -78,7 +78,7 @@ enum {
 	CHANNELS_CHANGE_ASYNC,
 	BUFFERING_ASYNC,
 	MESSAGE_ASYNC,
-	SPEED_WARNING_ASYNC,
+	SPEED_WARNING_ASYNC
 };
 
 typedef struct {
@@ -99,16 +99,20 @@ enum {
 	PROP_SEEKABLE,
 	PROP_SHOWCURSOR,
 	PROP_MEDIADEV,
-	PROP_SHOW_VISUALS,
+	PROP_SHOW_VISUALS
 };
 
-static int video_props[2] = {
+static int video_props[4] = {
 	XINE_PARAM_VO_BRIGHTNESS,
 	XINE_PARAM_VO_CONTRAST,
+	XINE_PARAM_VO_SATURATION,
+	XINE_PARAM_VO_HUE
 };
-static char *video_props_str[2] = {
+static char *video_props_str[4] = {
 	GCONF_PREFIX"/brightness",
 	GCONF_PREFIX"/contrast",
+	GCONF_PREFIX"/saturation",
+	GCONF_PREFIX"/hue"
 };
 
 struct BaconVideoWidgetPrivate {
@@ -532,7 +536,7 @@ load_video_out_driver (BaconVideoWidget *bvw, gboolean null_out)
 	const char *video_driver_id;
 	xine_vo_driver_t *vo_driver;
 
-	if (null_out == TRUE)
+	if (null_out != FALSE)
 	{
 		return xine_open_video_driver (bvw->priv->xine,
 				"none", XINE_VISUAL_TYPE_NONE, NULL);
@@ -581,11 +585,6 @@ load_video_out_driver (BaconVideoWidget *bvw, gboolean null_out)
 	 * we need to try loading the other ones, skipping dxr3 */
 
 	/* The types are hardcoded for now */
-	vo_driver = xine_open_video_driver (bvw->priv->xine, "xvmc",
-			XINE_VISUAL_TYPE_X11, (void *) &vis);
-	if (vo_driver)
-		return vo_driver;
-
 	vo_driver = xine_open_video_driver (bvw->priv->xine, "xv",
 			XINE_VISUAL_TYPE_X11, (void *) &vis);
 	if (vo_driver)
@@ -603,7 +602,7 @@ load_audio_out_driver (BaconVideoWidget *bvw, GError **err)
 	xine_ao_driver_t *ao_driver;
 	const char *audio_driver_id;
 
-	if (bvw->priv->null_out == TRUE)
+	if (bvw->priv->null_out != FALSE)
 		return NULL;
 
 	audio_driver_id = xine_config_register_string (bvw->priv->xine,
@@ -783,7 +782,7 @@ setup_config_stream (BaconVideoWidget *bvw)
 		return;
 
 	/* Setup brightness and contrast */
-	for (i = 0; i < 2; i++)
+	for (i = 0; i < 4; i++)
 	{
 		value = gconf_client_get_int (bvw->priv->gc, video_props_str[i], NULL);
 		/* avoid black screens */
@@ -917,19 +916,19 @@ generate_mouse_event (BaconVideoWidget *bvw, GdkEvent *event,
 	if (is_motion == FALSE && bevent->button != 1)
 		return FALSE;
 
-	if (is_motion == TRUE)
+	if (is_motion != FALSE)
 		retval = video_window_translate_point (bvw,
 				mevent->x, mevent->y, &x, &y);
 	else
 		retval = video_window_translate_point (bvw,
 				bevent->x, bevent->y, &x, &y);
 
-	if (retval == TRUE)
+	if (retval != FALSE)
 	{
 		xine_event_t event;
 		xine_input_data_t input;
 
-		if (is_motion == TRUE)
+		if (is_motion != FALSE)
 		{
 			event.type = XINE_EVENT_INPUT_MOUSE_MOVE;
 			input.button = 0; /* Just motion. */
@@ -1079,7 +1078,7 @@ bacon_video_widget_idle_signal (BaconVideoWidget *bvw)
 	switch (data->signal)
 	{
 	case RATIO:
-		bacon_video_widget_set_scale_ratio (bvw, 0);
+		bacon_video_widget_set_scale_ratio (bvw, 1);
 		break;
 	case TITLE_CHANGE_ASYNC:
 		g_signal_emit (G_OBJECT (bvw),
@@ -1165,7 +1164,13 @@ xine_event_message (BaconVideoWidget *bvw, xine_ui_message_data_t *data)
 		message = g_strdup_printf (_("A problem occured while loading a library or a decoder (%s)."), (char *) data + data->parameters);
 		break;
 	case XINE_MSG_ENCRYPTED_SOURCE:
-		message = g_strdup_printf (_("The source seems encrypted, and can't be read. Are you trying to play an encrypted DVD without libdvdcss?"));
+		if (strncmp (bvw->priv->mrl, "dvd:", 4) == 0)
+			message = g_strdup (_("The source seems encrypted, and can't be read. Are you trying to play an encrypted DVD without libdvdcss?"));
+		else
+			message = g_strdup (_("This file is encrypted and cannot be played back."));
+		break;
+	case XINE_MSG_SECURITY:
+		message = g_strdup (_("For security reasons, this movie can not be played back."));
 		break;
 	}
 
@@ -1444,8 +1449,7 @@ bacon_video_widget_button_press (GtkWidget *widget, GdkEventButton *event)
 {
 	BaconVideoWidget *bvw = (BaconVideoWidget *) widget;
 
-	if (generate_mouse_event (bvw, (GdkEvent *)event, FALSE) == TRUE)
-		return FALSE;
+	generate_mouse_event (bvw, (GdkEvent *)event, FALSE);
 
 	if (GTK_WIDGET_CLASS (parent_class)->button_press_event != NULL)
 		                (* GTK_WIDGET_CLASS (parent_class)->button_press_event) (widget, event);
@@ -1551,7 +1555,7 @@ bacon_video_widget_tick_send (BaconVideoWidget *bvw)
 	else
 		bvw->priv->is_live = TRUE;
 
-	if (ret == TRUE)
+	if (ret != FALSE)
 		g_signal_emit (G_OBJECT (bvw),
 				bvw_table_signals[TICK], 0,
 				(gint64) (current_time),
@@ -1634,7 +1638,6 @@ bacon_video_widget_open (BaconVideoWidget *bvw, const char *mrl,
 {
 	int error;
 
-	g_return_val_if_fail (bvw != NULL, FALSE);
 	g_return_val_if_fail (mrl != NULL, FALSE);
 	g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), FALSE);
 	g_return_val_if_fail (bvw->priv->xine != NULL, FALSE);
@@ -1859,8 +1862,9 @@ bacon_video_widget_close (BaconVideoWidget *bvw)
 	g_free (bvw->priv->mrl);
 	bvw->priv->mrl = NULL;
 
-	g_signal_emit (G_OBJECT (bvw),
-			bvw_table_signals[CHANNELS_CHANGE], 0, NULL);
+	if (bvw->priv->logo_mode == FALSE)
+		g_signal_emit (G_OBJECT (bvw),
+				bvw_table_signals[CHANNELS_CHANGE], 0, NULL);
 }
 
 /* Properties */
@@ -1954,7 +1958,7 @@ bacon_video_widget_set_logo (BaconVideoWidget *bvw, char *filename)
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET(bvw));
 	g_return_if_fail (bvw->priv->xine != NULL);
 
-	if (bacon_video_widget_open (bvw, filename, NULL) == TRUE) {
+	if (bacon_video_widget_open (bvw, filename, NULL) != FALSE) {
 		bacon_video_widget_play (bvw, NULL);
 	}
 }
@@ -2053,7 +2057,7 @@ bacon_video_widget_set_volume (BaconVideoWidget *bvw, int volume)
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
 	g_return_if_fail (bvw->priv->xine != NULL);
 
-	if (bacon_video_widget_can_set_volume (bvw) == TRUE)
+	if (bacon_video_widget_can_set_volume (bvw) != FALSE)
 	{
 		volume = CLAMP (volume, 0, 100);
 		xine_set_param (bvw->priv->stream,
@@ -2152,6 +2156,12 @@ bacon_video_widget_set_media_device (BaconVideoWidget *bvw, const char *path)
 	entry.str_value = g_strdup (path);
 	xine_config_update_entry (bvw->priv->xine, &entry);
 
+	/* VCD device for the new input plugin */
+	bvw_config_helper_string (bvw->priv->xine, "vcd.default_device",
+			path, &entry);
+	entry.str_value = g_strdup (path);
+	xine_config_update_entry (bvw->priv->xine, &entry);
+
 	/* CDDA device */
 	bvw_config_helper_string (bvw->priv->xine, "input.cdda_device",
 			path, &entry);
@@ -2355,7 +2365,7 @@ bacon_video_widget_set_visuals (BaconVideoWidget *bvw, const char *name)
 	}
 
 	speed = xine_get_param (bvw->priv->stream, XINE_PARAM_SPEED);
-	if (speed == XINE_SPEED_PAUSE && bvw->priv->using_vfx == TRUE)
+	if (speed == XINE_SPEED_PAUSE && bvw->priv->using_vfx != FALSE)
 	{
 		g_free (bvw->priv->queued_vis);
 		if (strcmp (name, bvw->priv->vis_name) == 0)
@@ -2383,7 +2393,7 @@ bacon_video_widget_set_visuals (BaconVideoWidget *bvw, const char *name)
 			oldvis = bvw->priv->vis;
 			bvw->priv->vis = newvis;
 
-			if (bvw->priv->using_vfx == TRUE)
+			if (bvw->priv->using_vfx != FALSE)
 			{
 				show_vfx_update (bvw, FALSE);
 				show_vfx_update (bvw, TRUE);
@@ -2644,7 +2654,7 @@ bacon_video_widget_set_scale_ratio (BaconVideoWidget *bvw, gfloat ratio)
 	g_return_if_fail (bvw->priv->xine != NULL);
 	g_return_if_fail (ratio >= 0);
 
-	if (bvw->priv->fullscreen_mode == TRUE)
+	if (bvw->priv->fullscreen_mode != FALSE)
 		return;
 
 	/* Try best fit for the screen */
@@ -2715,7 +2725,9 @@ bacon_video_widget_set_video_property (BaconVideoWidget *bvw,
 	g_return_if_fail (bvw != NULL);
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
 	g_return_if_fail (bvw->priv->xine != NULL);
-	g_return_if_fail ((value < 65535 && value > 0));
+
+	if ( !(value < 65535 && value > 0) )
+		return;
 
 	xine_set_param (bvw->priv->stream, video_props[type], value);
 	gconf_client_set_int (bvw->priv->gc, video_props_str[type], value, NULL);
@@ -3001,15 +3013,17 @@ GList
 {
 	GList *list = NULL;
 	int i;
-	char lang[16];
+	char lang[XINE_LANG_MAX];
 
 	for(i = 0; i < 32; i++)
 	{
 		memset (&lang, 0, sizeof (lang));
 
 		if (xine_get_audio_lang(bvw->priv->stream, i, lang) == 1)
+		{
 			list = g_list_prepend (list,
 					(gpointer) g_strdup (lang));
+		}
 	}
 
 	return g_list_reverse (list);
@@ -3018,6 +3032,9 @@ GList
 int
 bacon_video_widget_get_language (BaconVideoWidget *bvw)
 {
+	g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), -1);
+	g_return_val_if_fail (bvw->priv->stream != NULL, -1);
+
 	return xine_get_param (bvw->priv->stream,
 			XINE_PARAM_AUDIO_CHANNEL_LOGICAL);
 }
@@ -3025,6 +3042,9 @@ bacon_video_widget_get_language (BaconVideoWidget *bvw)
 void
 bacon_video_widget_set_language (BaconVideoWidget *bvw, int language)
 {
+	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
+	g_return_if_fail (bvw->priv->stream != NULL);
+
 	xine_set_param (bvw->priv->stream,
 			XINE_PARAM_AUDIO_CHANNEL_LOGICAL, language);
 }
@@ -3034,15 +3054,17 @@ GList
 {
 	GList *list = NULL;
 	int i;
-	char lang[16];
+	char lang[XINE_LANG_MAX];
 
 	for(i = 0; i < 32; i++)
 	{
 		memset (&lang, 0, sizeof (lang));
 
 		if (xine_get_spu_lang(bvw->priv->stream, i, lang) == 1)
+		{
 			list = g_list_prepend (list,
 					(gpointer) g_strdup (lang));
+		}
 	}
 
 	return g_list_reverse (list);
