@@ -25,8 +25,6 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <libxml/tree.h>
-#include <libxml/parser.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-desktop-item.h>
@@ -38,8 +36,6 @@
 #include "totem-pl-parser.h"
 #include "debug.h"
 
-#define READ_CHUNK_SIZE 8192
-#define MIME_READ_CHUNK_SIZE 1024
 #define PL_LEN (gtk_tree_model_iter_n_children (playlist->_priv->model, NULL))
 
 static void ensure_shuffled (TotemPlaylist *playlist, gboolean shuffle);
@@ -115,7 +111,6 @@ static void totem_playlist_init       (TotemPlaylist      *playlist);
 
 static void init_treeview (GtkWidget *treeview, TotemPlaylist *playlist);
 static gboolean totem_playlist_unset_playing (TotemPlaylist *playlist);
-static void totem_playlist_set_at_end (TotemPlaylist *playlist);
 
 GtkType
 totem_playlist_get_type (void)
@@ -145,14 +140,15 @@ totem_playlist_get_type (void)
 
 /* Helper functions */
 static gboolean
-gtk_tree_model_iter_previous (GtkTreeModel *tree_model, GtkTreeIter *iter)
+totem_playlist_gtk_tree_model_iter_previous (GtkTreeModel *tree_model,
+		GtkTreeIter *iter)
 {
 	GtkTreePath *path;
 	gboolean ret;
 
 	path = gtk_tree_model_get_path (tree_model, iter);
 	ret = gtk_tree_path_prev (path);
-	if (ret == TRUE)
+	if (ret != FALSE)
 		gtk_tree_model_get_iter (tree_model, iter, path);
 
 	gtk_tree_path_free (path);
@@ -160,7 +156,7 @@ gtk_tree_model_iter_previous (GtkTreeModel *tree_model, GtkTreeIter *iter)
 }
 
 static gboolean
-gtk_tree_path_equals (GtkTreePath *path1, GtkTreePath *path2)
+totem_playlist_gtk_tree_path_equals (GtkTreePath *path1, GtkTreePath *path2)
 {
 	char *str1, *str2;
 	gboolean retval;
@@ -201,6 +197,8 @@ totem_playlist_error (char *title, char *reason, TotemPlaylist *playlist)
 				"<b>%s</b>\n%s.", title_esc, reason_esc);
 	g_free (title_esc);
 	g_free (reason_esc);
+	gtk_dialog_set_has_separator (GTK_DIALOG (error_dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
 	gtk_dialog_set_default_response (GTK_DIALOG (error_dialog),
 			GTK_RESPONSE_OK);
 	gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (error_dialog)->label), TRUE);
@@ -244,6 +242,59 @@ totem_playlist_mrl_to_title (const gchar *mrl)
 	return filename_for_display;
 }
 
+static gboolean
+totem_playlist_is_media (const char *mrl)
+{
+	if (mrl == NULL)
+		return FALSE;
+
+	if (strncmp ("cdda:", mrl, strlen ("cdda:")) == 0)
+		return TRUE;
+	if (strncmp ("dvd:",mrl, strlen ("dvd:")) == 0)
+		return TRUE;
+	if (strncmp ("vcd:", mrl, strlen ("vcd:")) == 0)
+		return TRUE;
+
+	return FALSE;
+}
+
+static char*
+totem_playlist_create_full_path (const char *path)
+{
+	char *retval, *curdir, *curdir_withslash, *escaped;
+
+	g_return_val_if_fail (path != NULL, NULL);
+
+	if (strstr (path, "://") != NULL)
+		return g_strdup (path);
+	if (totem_playlist_is_media (path) != FALSE)
+		return g_strdup (path);
+
+	if (path[0] == '/')
+	{
+		escaped = gnome_vfs_escape_path_string (path);
+
+		retval = g_strdup_printf ("file://%s", escaped);
+		g_free (escaped);
+		return retval;
+	}
+
+	curdir = g_get_current_dir ();
+	escaped = gnome_vfs_escape_path_string (curdir);
+	curdir_withslash = g_strdup_printf ("file://%s%s",
+			escaped, G_DIR_SEPARATOR_S);
+	g_free (escaped);
+	g_free (curdir);
+
+	escaped = gnome_vfs_escape_path_string (path);
+	retval = gnome_vfs_uri_make_full_from_relative
+		(curdir_withslash, escaped);
+	g_free (curdir_withslash);
+	g_free (escaped);
+
+	return retval;
+}
+
 static void
 totem_playlist_save_get_iter_func (GtkTreeModel *model,
 		GtkTreeIter *iter, char **uri, char **title)
@@ -534,7 +585,7 @@ totem_playlist_remove_files (GtkWidget *widget, TotemPlaylist *playlist)
 	g_list_free (playlist->_priv->list);
 	playlist->_priv->list = NULL;
 
-	if (is_selected == TRUE)
+	if (is_selected != FALSE)
 	{
 		/* The current item was removed from the playlist */
 		if (next_pos != -1)
@@ -616,7 +667,7 @@ totem_playlist_save_files (GtkWidget *widget, TotemPlaylist *playlist)
 			g_free (tmp);
 		}
 
-		if (g_file_test (filename, G_FILE_TEST_EXISTS) == TRUE)
+		if (g_file_test (filename, G_FILE_TEST_EXISTS) != FALSE)
 		{
 			GtkWidget *dialog;
 
@@ -627,6 +678,8 @@ totem_playlist_save_files (GtkWidget *widget, TotemPlaylist *playlist)
 				 GTK_BUTTONS_NONE,
 				 _("A file named '%s' already exists.\nAre you sure you want to overwrite it?"),
 				 filename);
+			gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+			gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 			gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 					GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
@@ -822,7 +875,8 @@ static void
 treeview_row_changed (GtkTreeView *treeview, GtkTreePath *arg1,
 		GtkTreeViewColumn *arg2, TotemPlaylist *playlist)
 {
-	if (gtk_tree_path_equals (arg1, playlist->_priv->current) == TRUE)
+	if (totem_playlist_gtk_tree_path_equals
+			(arg1, playlist->_priv->current) != FALSE)
 		return;
 
 	if (playlist->_priv->current != NULL)
@@ -1097,10 +1151,17 @@ totem_playlist_init (TotemPlaylist *playlist)
 	playlist->_priv = g_new0 (TotemPlaylistPrivate, 1);
 	playlist->_priv->parser = totem_pl_parser_new ();
 
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "dvd:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "cdda:");
+	totem_pl_parser_add_ignored_scheme (playlist->_priv->parser, "vcd:");
+
 	g_signal_connect (G_OBJECT (playlist->_priv->parser),
 			"entry",
 			G_CALLBACK (totem_playlist_entry_parsed),
 			playlist);
+
+	gtk_dialog_set_has_separator (GTK_DIALOG (playlist), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (playlist), 5);
 }
 
 static void
@@ -1129,7 +1190,7 @@ totem_playlist_unrealize (GtkWidget *widget)
 
 	g_return_if_fail (widget != NULL);
 
-	if (GTK_WIDGET_MAPPED (widget) == TRUE)
+	if (GTK_WIDGET_MAPPED (widget) != FALSE)
 	{
 		gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
 	} else {
@@ -1275,7 +1336,7 @@ totem_playlist_add_one_mrl (TotemPlaylist *playlist, const char *mrl,
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
-	char *filename_for_display;
+	char *filename_for_display, *uri;
 
 	g_return_val_if_fail (GTK_IS_PLAYLIST (playlist), FALSE);
 	g_return_val_if_fail (mrl != NULL, FALSE);
@@ -1287,19 +1348,22 @@ totem_playlist_add_one_mrl (TotemPlaylist *playlist, const char *mrl,
 		filename_for_display = g_strdup (display_name);
 	}
 
+	uri = totem_playlist_create_full_path (mrl);
+
 	D("totem_playlist_add_one_mrl (): %s %s %s\n",
-				filename_for_display, mrl, display_name);
+				filename_for_display, uri, display_name);
 
 	store = GTK_LIST_STORE (playlist->_priv->model);
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter,
 			PIX_COL, NULL,
 			FILENAME_COL, filename_for_display,
-			URI_COL, mrl,
+			URI_COL, uri,
 			TITLE_CUSTOM_COL, display_name ? TRUE : FALSE,
 			-1);
 
 	g_free (filename_for_display);
+	g_free (uri);
 
 	if (playlist->_priv->current == NULL
 			&& playlist->_priv->shuffle == FALSE)
@@ -1397,7 +1461,7 @@ totem_playlist_has_previous_mrl (TotemPlaylist *playlist)
 	if (update_current_from_playlist (playlist) == FALSE)
 		return FALSE;
 
-	if (playlist->_priv->repeat == TRUE)
+	if (playlist->_priv->repeat != FALSE)
 		return TRUE;
 
 	if (playlist->_priv->shuffle == FALSE)
@@ -1406,7 +1470,7 @@ totem_playlist_has_previous_mrl (TotemPlaylist *playlist)
 				&iter,
 				playlist->_priv->current);
 
-		return gtk_tree_model_iter_previous
+		return totem_playlist_gtk_tree_model_iter_previous
 			(playlist->_priv->model, &iter);
 	} else {
 		if (playlist->_priv->current_shuffled == 0)
@@ -1426,7 +1490,7 @@ totem_playlist_has_next_mrl (TotemPlaylist *playlist)
 	if (update_current_from_playlist (playlist) == FALSE)
 		return FALSE;
 
-	if (playlist->_priv->repeat == TRUE)
+	if (playlist->_priv->repeat != FALSE)
 		return TRUE;
 
 	if (playlist->_priv->shuffle == FALSE)
@@ -1489,7 +1553,7 @@ totem_playlist_set_playing (TotemPlaylist *playlist, gboolean state)
 	if (&iter == NULL)
 		return FALSE;
 
-	if (state == TRUE)
+	if (state != FALSE)
 		gtk_list_store_set (store, &iter,
 				PIX_COL, playlist->_priv->icon,
 				-1);
@@ -1552,7 +1616,8 @@ totem_playlist_set_previous (TotemPlaylist *playlist)
 				&iter,
 				playlist->_priv->current);
 
-		gtk_tree_model_iter_previous (playlist->_priv->model, &iter);
+		totem_playlist_gtk_tree_model_iter_previous
+			(playlist->_priv->model, &iter);
 		gtk_tree_path_free (playlist->_priv->current);
 		playlist->_priv->current = gtk_tree_model_get_path
 			(playlist->_priv->model, &iter);
@@ -1660,7 +1725,7 @@ totem_playlist_set_at_start (TotemPlaylist *playlist)
 	update_current_from_playlist (playlist);
 }
 
-static void
+void
 totem_playlist_set_at_end (TotemPlaylist *playlist)
 {
 	int indice;
