@@ -21,6 +21,9 @@
 #include <libgnome/gnome-i18n.h>
 #include <gtk/gtkmessagedialog.h>
 #include <string.h>
+#include <stdio.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include "totem.h"
 #include "totem-private.h"
@@ -31,6 +34,36 @@
 
 #define PROPRIETARY_PLUGINS ".gnome2"G_DIR_SEPARATOR_S"totem-addons"
 
+static void
+totem_action_info (char *reason, Totem *totem)
+{
+	GtkWidget *parent, *error_dialog;
+
+	if (totem == NULL)
+		parent = NULL;
+	else
+		parent = totem->win;
+
+	error_dialog =
+		gtk_message_dialog_new (GTK_WINDOW (parent),
+				GTK_DIALOG_MODAL,
+				GTK_MESSAGE_INFO,
+				GTK_BUTTONS_OK,
+				"%s", reason);
+	gtk_dialog_set_has_separator (GTK_DIALOG (error_dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
+	gtk_dialog_set_default_response (GTK_DIALOG (error_dialog),
+			GTK_RESPONSE_OK);
+	g_signal_connect (G_OBJECT (error_dialog), "destroy", G_CALLBACK
+			(gtk_widget_destroy), error_dialog);
+	g_signal_connect (G_OBJECT (error_dialog), "response", G_CALLBACK
+			(gtk_widget_destroy), error_dialog);
+	gtk_window_set_modal (GTK_WINDOW (error_dialog), TRUE);
+
+	gtk_widget_show (error_dialog);
+}
+
+
 static gboolean
 totem_display_is_local (Totem *totem)
 {
@@ -79,6 +112,8 @@ ask_show_visuals (Totem *totem)
 				_("It seems you are running Totem remotely.\n"
 				"Are you sure you want to enable the visual "
 				"effects?"));
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 			GTK_RESPONSE_NO);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -128,7 +163,7 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
 	if (bacon_video_widget_set_show_visuals
 			(BACON_VIDEO_WIDGET (totem->bvw), value) == FALSE)
 	{
-		totem_action_error (_("The change of this setting will only "
+		totem_action_info (_("The change of this setting will only "
 					"take effect for the next movie, or "
 					"when Totem is restarted"),
 				totem);
@@ -138,12 +173,11 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
 static void
 on_checkbutton2_toggled (GtkToggleButton *togglebutton, Totem *totem)
 {
-	GtkWidget *item;
 	gboolean value;
 
 	value = gtk_toggle_button_get_active (togglebutton);
 
-	if (value == TRUE && totem_display_is_local (totem) == FALSE)
+	if (value != FALSE && totem_display_is_local (totem) == FALSE)
 	{
 		if (ask_show_visuals (totem) == FALSE)
 		{
@@ -172,8 +206,8 @@ on_tvout_toggled (GtkToggleButton *togglebutton, Totem *totem)
 	value = bacon_video_widget_set_tv_out
 		(BACON_VIDEO_WIDGET (totem->bvw), type);
 
-	if (value == TRUE)
-		totem_action_error (_("Switching on or off this type of TV-Out requires a restart to take effect."), totem);
+	if (value != FALSE)
+		totem_action_info (_("Switching on or off this type of TV-Out requires a restart to take effect."), totem);
 }
 
 static void
@@ -293,7 +327,7 @@ on_button1_clicked (GtkButton *button, Totem *totem)
 	GError *err = NULL;
 	char *path, *cmd, *filemanager;
 
-	path = path = g_build_path (G_DIR_SEPARATOR_S,
+	path = g_build_path (G_DIR_SEPARATOR_S,
 			g_get_home_dir (), PROPRIETARY_PLUGINS, NULL);
 
 	if (g_getenv ("KDE_STARTUP_ENV") && (filemanager = g_find_program_in_path("konqueror"))) {
@@ -306,11 +340,7 @@ on_button1_clicked (GtkButton *button, Totem *totem)
 
 	if (g_spawn_command_line_async (cmd, &err) == FALSE)
 	{
-		char *msg;
-
-		msg = g_strdup_printf ("Totem could not start the file manager\nReason: %s.", err->message);
-		totem_action_error (msg, totem);
-		g_free (msg);
+		totem_action_error (_("Totem could not start the file manager."), err->message, totem);
 		g_error_free (err);
 	}
 
@@ -337,8 +367,8 @@ visual_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
 		gconf_client_set_string (totem->gc, GCONF_PREFIX"/visual",
 				name, NULL);
 
-		if (bacon_video_widget_set_visuals (totem->bvw, name) == TRUE)
-			totem_action_error (_("Changing the visuals effect type will require a restart to take effect."), totem);
+		if (bacon_video_widget_set_visuals (totem->bvw, name) != FALSE)
+			totem_action_info (_("Changing the visuals effect type will require a restart to take effect."), totem);
 	}
 }
 
@@ -384,6 +414,26 @@ contrast_changed (GtkRange *range, Totem *totem)
 			BVW_VIDEO_CONTRAST, (int) i);
 }
 
+static void
+saturation_changed (GtkRange *range, Totem *totem)
+{
+	gdouble i;
+
+	i = gtk_range_get_value (range);
+	bacon_video_widget_set_video_property (totem->bvw,
+			BVW_VIDEO_SATURATION, (int) i);
+}
+
+static void
+hue_changed (GtkRange *range, Totem *totem)
+{
+	gdouble i;
+
+	i = gtk_range_get_value (range);
+	bacon_video_widget_set_video_property (totem->bvw,
+			BVW_VIDEO_HUE, (int) i);
+}
+
 static void
 audio_out_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
 {
@@ -447,19 +497,15 @@ totem_setup_preferences (Totem *totem)
 			(BACON_CD_SELECTION (item));
 		gconf_client_set_string (totem->gc, GCONF_PREFIX"/mediadev",
 				mediadev, NULL);
-		bacon_video_widget_set_media_device
-			(BACON_VIDEO_WIDGET (totem->bvw), mediadev);
-	} else {
-		bacon_video_widget_set_media_device
-			(BACON_VIDEO_WIDGET (totem->bvw), mediadev);
 	}
+	bacon_video_widget_set_media_device
+		(BACON_VIDEO_WIDGET (totem->bvw), mediadev);
 
-	bacon_cd_selection_set_device (BACON_CD_SELECTION (item),
-			gconf_client_get_string
-			(totem->gc, GCONF_PREFIX"/mediadev", NULL));
 	g_signal_connect (G_OBJECT (item), "device-changed",
 			G_CALLBACK (on_combo_entry1_changed), totem);
 
+	bacon_cd_selection_set_device (BACON_CD_SELECTION (item), mediadev);
+
 	/* Connection Speed */
 	connection_speed = bacon_video_widget_get_connection_speed (totem->bvw);
 	item = glade_xml_get_widget (totem->xml, "tpw_speed_optionmenu");
@@ -483,7 +529,7 @@ totem_setup_preferences (Totem *totem)
 	item = glade_xml_get_widget (totem->xml, "tpw_visuals_checkbutton");
 	show_visuals = gconf_client_get_bool (totem->gc,
 			GCONF_PREFIX"/show_vfx", NULL);
-	if (is_local == FALSE && show_visuals == TRUE)
+	if (is_local == FALSE && show_visuals != FALSE)
 		show_visuals = ask_show_visuals (totem);
 
 	gtk_toggle_button_set_active
@@ -502,7 +548,7 @@ totem_setup_preferences (Totem *totem)
 	if (visual == NULL || strcmp (visual, "") == 0)
 		visual = g_strdup ("goom");
 
-	i = 0;
+	i = found = 0;
 	for (l = list; l != NULL; l = l->next)
 	{
 		const char *name = l->data;
@@ -548,6 +594,22 @@ totem_setup_preferences (Totem *totem)
 	g_signal_connect (G_OBJECT (item), "value-changed",
 			G_CALLBACK (contrast_changed), totem);
 
+	/* Saturation */
+	item = glade_xml_get_widget (totem->xml, "tpw_saturation_scale");
+	i = bacon_video_widget_get_video_property (totem->bvw,
+			BVW_VIDEO_SATURATION);
+	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
+	g_signal_connect (G_OBJECT (item), "value-changed",
+			G_CALLBACK (saturation_changed), totem);
+
+	/* Hue */
+	item = glade_xml_get_widget (totem->xml, "tpw_hue_scale");
+	i = bacon_video_widget_get_video_property (totem->bvw,
+			BVW_VIDEO_HUE);
+	gtk_range_set_value (GTK_RANGE (item), (gdouble) i);
+	g_signal_connect (G_OBJECT (item), "value-changed",
+			G_CALLBACK (hue_changed), totem);
+
 	/* Sound output type */
 	item = glade_xml_get_widget (totem->xml, "tpw_sound_output_optionmenu");
 	audio_out = bacon_video_widget_get_audio_out_type (totem->bvw);
@@ -597,6 +659,7 @@ totem_preferences_tvout_setup (Totem *totem)
 		break;
 	default:
 		g_assert_not_reached ();
+		name = NULL;
 	}
 
 	item = glade_xml_get_widget (totem->xml, name);
@@ -631,4 +694,3 @@ totem_preferences_visuals_setup (Totem *totem)
 
 	bacon_video_widget_set_visuals (totem->bvw, visual);
 }
-
