@@ -77,8 +77,7 @@ add_holes_to_pixbuf (GdkPixbuf *pixbuf, int width, int height)
 	char *filename;
 	int i;
 
-	filename = g_build_filename (G_DIR_SEPARATOR_S, DATADIR,
-			"totem", "filmholes.png", NULL);
+	filename = g_build_filename (DATADIR, "totem", "filmholes.png", NULL);
 	holes = gdk_pixbuf_new_from_file (filename, NULL);
 	g_free (filename);
 
@@ -89,7 +88,7 @@ add_holes_to_pixbuf (GdkPixbuf *pixbuf, int width, int height)
 	}
 
 	g_assert (gdk_pixbuf_get_has_alpha (pixbuf) == FALSE);
-	g_assert (gdk_pixbuf_get_has_alpha (holes) == TRUE);
+	g_assert (gdk_pixbuf_get_has_alpha (holes) != FALSE);
 	tmp = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
 
 	for (i = 0; i < height; i += gdk_pixbuf_get_height (holes))
