@@ -272,14 +272,12 @@ on_about1_activate (GtkButton *button, Vanity *vanity)
 static char *
 screenshot_make_filename_helper (char *filename, gboolean desktop_exists)
 {
-	if (desktop_exists == TRUE)
+	if (desktop_exists != FALSE)
 	{
-		return g_build_filename (G_DIR_SEPARATOR_S,
-				g_get_home_dir (), ".gnome-desktop",
+		return g_build_filename (g_get_home_dir (), ".gnome-desktop",
 				filename, NULL);
 	} else {
-		return g_build_filename (G_DIR_SEPARATOR_S,
-				g_get_home_dir (), filename, NULL);
+		return g_build_filename (g_get_home_dir (), filename, NULL);
 	}
 }
 
@@ -302,13 +300,13 @@ screenshot_make_filename (Vanity *vanity)
 	desktop_exists = g_file_test (fullpath, G_FILE_TEST_EXISTS);
 	g_free (fullpath);
 
-	if (on_desktop == TRUE)
+	if (on_desktop != FALSE)
 	{
 		filename = g_strdup_printf (_("Screenshot%d.png"), i);
 		fullpath = screenshot_make_filename_helper (filename,
 				desktop_exists);
 
-		while (g_file_test (fullpath, G_FILE_TEST_EXISTS) == TRUE
+		while (g_file_test (fullpath, G_FILE_TEST_EXISTS) != FALSE
 				&& i < G_MAXINT)
 		{
 			i++;
@@ -702,8 +700,7 @@ main (int argc, char **argv)
 	g_free (filename);
 
 	vanity->win = glade_xml_get_widget (vanity->xml, "app1");
-	filename = g_build_filename (G_DIR_SEPARATOR_S, DATADIR,
-			"totem", "vanity.png", NULL);
+	filename = g_build_filename (DATADIR, "totem", "vanity.png", NULL);
 	gtk_window_set_default_icon_from_file (filename, NULL);
 	g_free (filename);
 
